package models

import (
	_ "github.com/ollama/ollama/model/models/bert"
	_ "github.com/ollama/ollama/model/models/deepseek2"
	_ "github.com/ollama/ollama/model/models/deepseekocr"
	_ "github.com/ollama/ollama/model/models/gemma2"
	_ "github.com/ollama/ollama/model/models/gemma3"
	_ "github.com/ollama/ollama/model/models/gemma3n"
	_ "github.com/ollama/ollama/model/models/glm4moelite"
	_ "github.com/ollama/ollama/model/models/glmocr"
	_ "github.com/ollama/ollama/model/models/gptoss"
	_ "github.com/ollama/ollama/model/models/lfm2"
	_ "github.com/ollama/ollama/model/models/llama"
	_ "github.com/ollama/ollama/model/models/llama4"
	_ "github.com/ollama/ollama/model/models/mistral3"
	_ "github.com/ollama/ollama/model/models/mllama"
	_ "github.com/ollama/ollama/model/models/nomicbert"
	_ "github.com/ollama/ollama/model/models/olmo3"
	_ "github.com/ollama/ollama/model/models/qwen2"
	_ "github.com/ollama/ollama/model/models/qwen25vl"
	_ "github.com/ollama/ollama/model/models/qwen3"
	_ "github.com/ollama/ollama/model/models/qwen3next"
	_ "github.com/ollama/ollama/model/models/qwen3vl"
)
